@@ -17,7 +17,6 @@ class _Config:
         "DEFAULT_AUTOPLAY",
         "DEFAULT_VOLUME",
         "DEFAULT_CROSSFADE",
-        "DEFAULT_GAPLESS",
         "SAMPLING_RATE",
         "CHANNELS",
         "FRAME_LENGTH",
@@ -50,12 +49,11 @@ class _Config:
         self.DEFAULT_AUTOPLAY: bool = True
         self.DEFAULT_VOLUME: float = 1.0
         self.DEFAULT_CROSSFADE: float = 10.0
-        self.DEFAULT_GAPLESS: bool = False
 
         # AUDIO
         self.SAMPLING_RATE: int = 48000
         self.CHANNELS: int = 2
-        self.FRAME_LENGTH: int = 20
+        self.FRAME_LENGTH: int = 60  # 2.5, 5, 10, 20, 40, 60
         self.SAMPLE_SIZE: int = 4
         self.EXPECTED_PACKETLOSS: int = 0
         self.BITRATE: int = 128
