@@ -14,6 +14,13 @@ class NoSearchResults(DiscodoException):
     pass
 
 
+class WebsocketConnectionClosed(DiscodoException):
+    def __init__(self, socket, code=None) -> None:
+        self.code = code or socket.close_code
+
+        super().__init__(f"Websocket connection closed with {self.code}")
+
+
 class VoiceClientNotFound(DiscodoException):
     pass
 
