@@ -1,4 +1,4 @@
 from . import opus
 from .AudioFifo import AudioFifo
 from .AudioFilter import AudioFilter
-from .encrypt import Encrypter
+from .encrypt import Cipher
