@@ -7,6 +7,7 @@ from typing import Coroutine
 
 import av
 
+from ..config import Config
 from ..natives import AudioFifo, AudioFilter
 from ..utils.threadLock import withLock
 
@@ -70,8 +71,8 @@ class PyAVSource:
             self._position
             - (
                 self.AudioFifo.samples
-                / 960
-                / 50
+                / Config.SAMPLES_PER_FRAME
+                / (1000 / Config.FRAME_LENGTH)
                 * (float(self.filter["atempo"]) if "atempo" in self.filter else 1.0)
             ),
             2,
